@@ -1,26 +1,33 @@
 extern crate phf_codegen;
 
 use std::env;
+use std::error::Error;
 use std::fs::File;
+use std::io::BufRead;
 use std::io::{BufReader, BufWriter, Write};
 use std::path::Path;
-use std::error::Error;
-use std::io::BufRead;
 
 fn titlecase_word(word: &str) -> String {
-    word.chars().enumerate()
-        .map(|(i, c)| if i == 0 { c.to_uppercase().collect::<String>() } else { c.to_lowercase().collect::<String>() })
+    word.chars()
+        .enumerate()
+        .map(|(i, c)| {
+            if i == 0 {
+                c.to_uppercase().collect::<String>()
+            } else {
+                c.to_lowercase().collect::<String>()
+            }
+        })
         .collect()
 }
 
 fn main() {
-    let path_txt = Path::new(&env::var("CARGO_MANIFEST_DIR").unwrap()).join("scripts/tls-ciphersuites.txt");
+    let path_txt =
+        Path::new(&env::var("CARGO_MANIFEST_DIR").unwrap()).join("scripts/tls-ciphersuites.txt");
     let display = path_txt.display();
     let file = match File::open(&path_txt) {
         // The `description` method of `io::Error` returns a string that
         // describes the error
-        Err(why) => panic!("couldn't open {}: {}", display,
-                                                   why.description()),
+        Err(why) => panic!("couldn't open {}: {}", display, why.description()),
         Ok(file) => file,
     };
     let f = BufReader::new(file);
@@ -28,11 +35,10 @@ fn main() {
     let path = Path::new(&env::var("OUT_DIR").unwrap()).join("codegen.rs");
     let mut file = BufWriter::new(File::create(&path).unwrap());
 
-    write!(&mut file, "pub static CIPHERS: phf::Map<u16, TlsCipherSuite> = ").unwrap();
     let mut map = phf_codegen::Map::new();
     for line in f.lines() {
         let l = line.unwrap();
-        let mut v : Vec<&str> = l.split(':').collect();
+        let mut v: Vec<&str> = l.split(':').collect();
 
         if v[5].is_empty() {
             v[5] = "NULL"
@@ -41,7 +47,7 @@ fn main() {
         let au = match v[3] {
             "SRP+DSS" => String::from("Srp_Dss"),
             "SRP+RSA" => String::from("Srp_Rsa"),
-            _ => titlecase_word(v[3]).replace("+","_"),
+            _ => titlecase_word(v[3]).replace("+", "_"),
         };
 
         let enc = match v[4] {
@@ -50,16 +56,15 @@ fn main() {
             _ => titlecase_word(v[4]),
         };
 
-        let mac = String::from (
-            match v[7] {
-                "NULL" => "Null",
-                "HMAC-MD5" => "HmacMd5",
-                "HMAC-SHA1" => "HmacSha1",
-                "HMAC-SHA256" => "HmacSha256",
-                "HMAC-SHA384" => "HmacSha384",
-                "AEAD" => "Aead",
-                _ => panic!("Unknown mac {}", v[7]),
-            });
+        let mac = String::from(match v[7] {
+            "NULL" => "Null",
+            "HMAC-MD5" => "HmacMd5",
+            "HMAC-SHA1" => "HmacSha1",
+            "HMAC-SHA256" => "HmacSha256",
+            "HMAC-SHA384" => "HmacSha384",
+            "AEAD" => "Aead",
+            _ => panic!("Unknown mac {}", v[7]),
+        });
 
         let key = u16::from_str_radix(v[0], 16).unwrap();
         let val =
@@ -75,10 +80,13 @@ fn main() {
             v[8], // mac_size
             ).clone();
 
-        map.entry(key,val.as_str());
-    };
+        map.entry(key, val.as_str());
+    }
 
-    map.build(&mut file).unwrap();
-    write!(&mut file, ";\n").unwrap();
+    writeln!(
+        &mut file,
+        "pub static CIPHERS: phf::Map<u16, TlsCipherSuite> = {};",
+        map.build()
+    )
+    .unwrap();
 }
-
