@@ -1,4 +1,5 @@
-use nom::{be_u8,be_u16,IResult};
+use nom::number::streaming::{be_u16, be_u8};
+use nom::IResult;
 
 /// Hash algorithms, as defined in [RFC5246]
 #[derive(Debug, PartialEq, Eq)]
@@ -90,7 +91,6 @@ impl SignatureScheme {
     }
 }
 
-
 /// DigitallySigned structure from [RFC2246] section 4.7
 /// has no algorithm definition.
 /// This should be deprecated in favor if
@@ -99,41 +99,41 @@ impl SignatureScheme {
 pub struct DigitallySigned<'a> {
     pub alg: Option<SignatureAndHashAlgorithm>,
     // pub alg: Option<u16>, // SignatureScheme
-    pub data: &'a[u8],
+    pub data: &'a [u8],
 }
 
-
-
-
-
-
-named!(pub parse_digitally_signed_old<DigitallySigned>,
+named! {pub parse_digitally_signed_old<DigitallySigned>,
     map!(
-        length_bytes!(be_u16),
+        length_data!(be_u16),
         |d| { DigitallySigned{ alg:None, data:d } }
     )
-);
+}
 
-named!(pub parse_digitally_signed<DigitallySigned>,
+named! {pub parse_digitally_signed<DigitallySigned>,
     do_parse!(
         h: be_u8 >>
         s: be_u8 >>
-        d: length_bytes!(be_u16) >>
+        d: length_data!(be_u16) >>
         ( DigitallySigned{
             alg: Some( SignatureAndHashAlgorithm{ hash:HashAlgorithm(h), sign:SignAlgorithm(s) } ),
             data: d,
         })
     )
-);
+}
 
 /// Parse DigitallySigned object, depending on the `ext` parameter which should
 /// be true if the TLS client has sent the `signature_algorithms` extension
-pub fn parse_content_and_signature<'a,F,T:'a>(i: &'a[u8], fun: F, ext: bool) -> IResult<&'a[u8],(T,DigitallySigned)>
-  where F: Fn(&'a[u8]) -> IResult<&[u8],T>
+pub fn parse_content_and_signature<'a, F, T: 'a>(
+    i: &'a [u8],
+    fun: F,
+    ext: bool,
+) -> IResult<&'a [u8], (T, DigitallySigned)>
+where
+    F: Fn(&'a [u8]) -> IResult<&[u8], T>,
 {
     if ext {
-        pair!(i,fun,parse_digitally_signed)
+        pair!(i, fun, parse_digitally_signed)
     } else {
-        pair!(i,fun,parse_digitally_signed_old)
+        pair!(i, fun, parse_digitally_signed_old)
     }
 }
